import * as React from 'react';
import createResource from '../cache/createResource';

type StylesheetProps = {
    href: string;
    media?: string;
};

export const StylesheetResource = createResource(
    load,
    // @ts-ignore
    ({ href, media }) => `${href}.${media}`
);

function load({ href, media = 'all' }: StylesheetProps) {
    return new Promise((resolve, reject) => {
        const link = document.createElement('link');
        link.rel = 'stylesheet';
        link.href = href;
        link.media = media;
        link.onload = resolve;
        link.onerror = reject;
        document.body.appendChild(link);
    });
}

const Stylesheet: React.FC<StylesheetProps> = props => {
    StylesheetResource.read(props);
    return <link {...props} />;
};

export const useStylesheet = (props: StylesheetProps) => {
    return StylesheetResource.read(props);
}

export default Stylesheet;
